@@ -54,7 +54,7 @@ class Exceptions:
 
 class STSClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
     """
 
@@ -71,21 +71,21 @@ class STSClient(BaseClient):
         *,
         RoleArn: str,
         RoleSessionName: str,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
-        Policy: str = None,
-        DurationSeconds: int = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        TransitiveTagKeys: Sequence[str] = None,
-        ExternalId: str = None,
-        SerialNumber: str = None,
-        TokenCode: str = None,
-        SourceIdentity: str = None
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        Policy: str = ...,
+        DurationSeconds: int = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        TransitiveTagKeys: Sequence[str] = ...,
+        ExternalId: str = ...,
+        SerialNumber: str = ...,
+        TokenCode: str = ...,
+        SourceIdentity: str = ...
     ) -> AssumeRoleResponseTypeDef:
         """
         Returns a set of temporary security credentials that you can use to access
         Amazon Web Services resources that you might not normally have access to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.assume_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role)
         """
 
@@ -95,15 +95,15 @@ class STSClient(BaseClient):
         RoleArn: str,
         PrincipalArn: str,
         SAMLAssertion: str,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
-        Policy: str = None,
-        DurationSeconds: int = None
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        Policy: str = ...,
+        DurationSeconds: int = ...
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
         Returns a set of temporary security credentials for users who have been
         authenticated via a SAML authentication response.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.assume_role_with_saml)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_saml)
         """
 
@@ -113,16 +113,16 @@ class STSClient(BaseClient):
         RoleArn: str,
         RoleSessionName: str,
         WebIdentityToken: str,
-        ProviderId: str = None,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
-        Policy: str = None,
-        DurationSeconds: int = None
+        ProviderId: str = ...,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        Policy: str = ...,
+        DurationSeconds: int = ...
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
         Returns a set of temporary security credentials for users who have been
         authenticated in a mobile or web application with a web identity provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_web_identity)
         """
 
@@ -130,7 +130,7 @@ class STSClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can_paginate)
         """
 
@@ -141,21 +141,21 @@ class STSClient(BaseClient):
         Decodes additional information about the authorization status of a request from
         an encoded message returned in response to an Amazon Web Services request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.decode_authorization_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode_authorization_message)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate_presigned_url)
         """
 
@@ -163,7 +163,7 @@ class STSClient(BaseClient):
         """
         Returns the account identifier for the specified access key ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.get_access_key_info)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_access_key_info)
         """
 
@@ -172,7 +172,7 @@ class STSClient(BaseClient):
         Returns details about the IAM user or role whose credentials are used to call
         the operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.get_caller_identity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_caller_identity)
         """
 
@@ -180,26 +180,26 @@ class STSClient(BaseClient):
         self,
         *,
         Name: str,
-        Policy: str = None,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = None,
-        DurationSeconds: int = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Policy: str = ...,
+        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        DurationSeconds: int = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> GetFederationTokenResponseTypeDef:
         """
         Returns a set of temporary security credentials (consisting of an access key ID,
         a secret access key, and a security token) for a federated user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.get_federation_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_federation_token)
         """
 
     def get_session_token(
-        self, *, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
+        self, *, DurationSeconds: int = ..., SerialNumber: str = ..., TokenCode: str = ...
     ) -> GetSessionTokenResponseTypeDef:
         """
         Returns a set of temporary credentials for an Amazon Web Services account or IAM
         user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/sts.html#STS.Client.get_session_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_session_token)
         """
